package ctbrec.recorder.postprocessing;
import java.io.File;
import java.io.IOException;
import java.util.Objects;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.io.Files;

import ctbrec.Recording;

public class Rename extends AbstractPlaceholderAwarePostProcessor {

    private static final Logger LOG = LoggerFactory.getLogger(Rename.class);
    public static final String FILE_NAME_TEMPLATE = "filename.template";
    public static final String DEFAULT = "${modelSanitizedName}_${localDateTime}.${fileSuffix}";

    @Override
    public String getName() {
        return "rename";
    }

    @Override
    public void postprocess(Recording rec) throws IOException {
        String filenameTemplate = getConfig().getOrDefault(FILE_NAME_TEMPLATE, DEFAULT);
        String filename = fillInPlaceHolders(filenameTemplate, rec);
        File src = rec.getPostProcessedFile();
        File target = new File(src.getParentFile(), filename);
        if (Objects.equals(src, target)) {
            return;
        }
        LOG.info("Renaming {} to {}", src.getName(), target.getName());
        Files.move(rec.getPostProcessedFile(), target);
        rec.setPostProcessedFile(target);
        if (Objects.equals(src, rec.getAbsoluteFile())) {
            rec.setAbsoluteFile(target);
        }
        rec.getAssociatedFiles().remove(src.getCanonicalPath());
        rec.getAssociatedFiles().add(target.getCanonicalPath());
    }

    @Override
    public String toString() {
        String s = getName();
        if (getConfig().containsKey(FILE_NAME_TEMPLATE)) {
            s += " [" + getConfig().get(FILE_NAME_TEMPLATE) + ']';
        }
        return s;
    }
}
